import React, { useState, useEffect, useContext } from 'react';
import Cookies from 'js-cookie';
import { Route, Redirect } from 'react-router-dom';

var Auth = React.createContext(null);
var AuthContextProvider = Auth.Provider;
var AuthContext = Auth;

var TokenObject = /*#__PURE__*/function () {
  function TokenObject(authCookieName, authTimeCookieName, stateCookieName, cookieDomain, cookieSecure) {
    this.authCookieName = authCookieName;
    this.authTimeCookieName = authTimeCookieName;
    this.stateCookieName = stateCookieName;
    this.cookieDomain = cookieDomain;
    this.cookieSecure = cookieSecure;
  }

  var _proto = TokenObject.prototype;

  _proto.setToken = function setToken(authToken, expiresAt, authState) {
    Cookies.set(this.authCookieName, authToken, {
      expires: expiresAt,
      domain: this.cookieDomain,
      secure: this.cookieSecure
    });
    Cookies.set(this.authTimeCookieName, expiresAt, {
      expires: expiresAt,
      domain: this.cookieDomain,
      secure: this.cookieSecure
    });
    Cookies.set(this.stateCookieName, authState, {
      expires: expiresAt,
      domain: this.cookieDomain,
      secure: this.cookieSecure
    });
  };

  _proto.removeToken = function removeToken() {
    Cookies.remove(this.authCookieName);
    Cookies.remove(this.authTimeCookieName);
    Cookies.remove(this.stateCookieName);
  };

  _proto.initialToken = function initialToken() {
    var authCookie = Cookies.get(this.authCookieName);
    var authTimeCookie = Cookies.get(this.authTimeCookieName);
    var stateCookie = Cookies.get(this.stateCookieName);

    if (authCookie !== undefined && authTimeCookie !== undefined) {
      var token = authCookie;
      var expiresAt = new Date(authTimeCookie);
      var authState;

      try {
        authState = stateCookie !== undefined ? JSON.parse(stateCookie) : '';
      } catch (e) {
        authState = '';
      }

      return {
        authToken: token,
        expireAt: expiresAt,
        authState: authState
      };
    } else {
      return {
        authToken: null,
        expireAt: null,
        authState: null
      };
    }
  };

  _proto.syncTokens = function syncTokens(authState) {
    if (authState.authToken === undefined || authState.authToken === null || authState.expireAt === null || authState.authState === null) {
      this.removeToken();
    } else {
      this.setToken(authState.authToken, authState.expireAt, authState.authState);
    }
  };

  return TokenObject;
}();

var AuthProvider = function AuthProvider(_ref) {
  var children = _ref.children,
      authCookieName = _ref.authCookieName,
      authTimeCookieName = _ref.authTimeCookieName,
      stateCookieName = _ref.stateCookieName,
      cookieDomain = _ref.cookieDomain,
      cookieSecure = _ref.cookieSecure;
  var JwtTokenObject = new TokenObject(authCookieName, authTimeCookieName, stateCookieName, cookieDomain, cookieSecure);

  var _useState = useState(JwtTokenObject.initialToken()),
      authState = _useState[0],
      setAuthState = _useState[1];

  useEffect(function () {
    JwtTokenObject.syncTokens(authState);
  }, [authState]);
  return React.createElement(AuthContextProvider, {
    value: {
      authState: authState,
      setAuthState: setAuthState
    }
  }, children);
};

function _extends() {
  _extends = Object.assign || function (target) {
    for (var i = 1; i < arguments.length; i++) {
      var source = arguments[i];

      for (var key in source) {
        if (Object.prototype.hasOwnProperty.call(source, key)) {
          target[key] = source[key];
        }
      }
    }

    return target;
  };

  return _extends.apply(this, arguments);
}

function _objectWithoutPropertiesLoose(source, excluded) {
  if (source == null) return {};
  var target = {};
  var sourceKeys = Object.keys(source);
  var key, i;

  for (i = 0; i < sourceKeys.length; i++) {
    key = sourceKeys[i];
    if (excluded.indexOf(key) >= 0) continue;
    target[key] = source[key];
  }

  return target;
}

var PrivateRoute = function PrivateRoute(_ref) {
  var Component = _ref.Component,
      loginPath = _ref.loginPath,
      rest = _objectWithoutPropertiesLoose(_ref, ["Component", "loginPath"]);

  var context = useContext(AuthContext);

  var isAuth = function isAuth() {
    if ((context === null || context === void 0 ? void 0 : context.authState.authToken) && (context === null || context === void 0 ? void 0 : context.authState.expireAt)) {
      if (new Date(context.authState.expireAt) > new Date()) {
        return true;
      } else {
        console.log('RAJ :: Token Expired');
        context.setAuthState({
          authToken: null,
          expireAt: null,
          authState: null
        });
        return false;
      }
    } else {
      return false;
    }
  };

  return React.createElement(Route, Object.assign({}, rest, {
    render: function render(props) {
      return isAuth() ? React.createElement(Component, {
        props: props
      }) : React.createElement(Redirect, {
        to: loginPath
      });
    }
  }));
};

var useSignIn = function useSignIn() {
  var c = useContext(AuthContext);
  return function (token, expiresIn, authState) {
    var expTime = new Date(new Date().getTime() + expiresIn * 60 * 1000);

    try {
      if (c) {
        c.setAuthState(function (prevState) {
          return _extends({}, prevState, {
            authToken: token,
            expireAt: expTime,
            authState: authState
          });
        });
        console.log('RAJ :: Signing In');
        return true;
      } else {
        return false;
      }
    } catch (e) {
      console.error(e);
      return false;
    }
  };
};

var useSignOut = function useSignOut() {
  var c = useContext(AuthContext);
  return function () {
    try {
      if (c === null || c === void 0 ? void 0 : c.authState.authToken) {
        c.setAuthState(function (prevState) {
          return _extends({}, prevState, {
            authToken: null,
            expireAt: null,
            authState: null
          });
        });
        console.log('RAJ :: Signing Out');
        return true;
      } else {
        return false;
      }
    } catch (e) {
      return false;
    }
  };
};

var useAuth = function useAuth() {
  var c = useContext(AuthContext);
  return function () {
    return c === null || c === void 0 ? void 0 : c.authState;
  };
};

var useAuthHeader = function useAuthHeader() {
  var c = useContext(AuthContext);
  return function () {
    if (c === null || c === void 0 ? void 0 : c.authState) {
      return "Bearer " + c.authState.authToken;
    } else {
      return "Bearer ";
    }
  };
};

export { AuthProvider, PrivateRoute, useAuth, useAuthHeader, useSignIn, useSignOut };
//# sourceMappingURL=index.modern.js.map
